@@ -7,18 +7,24 @@ use 5.010_000;
 use File::ShareDir 'dist_dir';
 use Path::Class;
 
-our $VERSION = '2.004002';
+our $VERSION = '2.006000';
 
 BEGIN {
   if (not length ($ENV{DANCER_APPDIR} || '')
       or not -f file($ENV{DANCER_APPDIR}, 'config.yml')) {
 
       my $auto = dir(dist_dir('App-Netdisco'))->absolute;
+      my $home = ($ENV{NETDISCO_HOME} || $ENV{HOME});
 
       $ENV{DANCER_APPDIR}  ||= $auto->stringify;
       $ENV{DANCER_CONFDIR} ||= $auto->stringify;
 
-      $ENV{DANCER_ENVDIR} ||= $auto->subdir('environments')->stringify;
+      my $test_envdir = dir($home, 'environments')->stringify;
+      $ENV{DANCER_ENVDIR} ||= (-d $test_envdir
+        ? $test_envdir : $auto->subdir('environments')->stringify);
+
+      $ENV{DANCER_ENVIRONMENT} ||= 'deployment';
+
       $ENV{DANCER_PUBLIC} ||= $auto->subdir('public')->stringify;
       $ENV{DANCER_VIEWS}  ||= $auto->subdir('views')->stringify;
   }
@@ -49,7 +55,8 @@ yet a device poller, so please still use the old Netdisco's discovery, arpnip,
 and macsuck.
 
 If you have any trouble getting the frontend running, speak to someone in the
-C<#netdisco> IRC channel (on freenode).
+C<#netdisco> IRC channel (on freenode). Before installing or upgrading please
+review the latest L<Release Notes|App::Netdisco::Manual::ReleaseNotes>.
 
 =head1 Dependencies
 
@@ -83,17 +90,21 @@ PostgreSQL user for the Netdisco application:
 
 =head1 Installation
 
+The following is a general guide which works well in most circumstances. It
+assumes you have a user C<netdisco> on your system, that you want to perform
+an on-line installation, and have the application run self-contained from
+within that user's home. There are alternatives: see the
+L<Deployment|App::Netdisco::Manual::Deployment> documentation for further
+details.
+
 To avoid muddying your system, use the following script to download and
 install Netdisco and its dependencies into the C<netdisco> user's home area
-(C<~netdisco/perl5>).
+(C<~netdisco/perl5>):
 
  su - netdisco
- curl -L http://cpanmin.us/ | perl - --notest --quiet \
-     --local-lib ~/perl5 \
-     App::cpanminus App::local::lib::helper App::Netdisco
+ curl -L http://cpanmin.us/ | perl - --notest --verbose --local-lib ~/perl5 App::Netdisco
 
-Link some of the newly installed apps into the C<netdisco> user's C<$PATH>,
-e.g. C<~netdisco/bin>:
+Link some of the newly installed apps into a handy location:
 
  mkdir ~/bin
  ln -s ~/perl5/bin/{localenv,netdisco-*} ~/bin/
@@ -109,14 +120,15 @@ Make a directory for your local configuration and copy the configuration
 template from this distribution:
 
  mkdir ~/environments
- cp ~/perl5/lib/perl5/auto/share/dist/App-Netdisco/environments/development.yml ~/environments
- chmod +w ~/environments/development.yml
+ cp ~/perl5/lib/perl5/auto/share/dist/App-Netdisco/environments/deployment.yml ~/environments
+ chmod +w ~/environments/deployment.yml
 
 Edit the file and change the database connection parameters to match those for
 your local system (that is, the C<dsn>, C<user> and C<pass>).
 
-Optionally, in the same file uncomment and edit the C<domain_suffix> setting
-to be appropriate for your local site.
+In the same file uncomment and edit the C<domain_suffix> setting to be
+appropriate for your local site. Optionally, set the C<no_auth> value to true
+if you wish to skip user authentication in the web interface.
 
 =head1 Bootstrap
 
@@ -125,76 +137,89 @@ release of Netdisco (1.x). You also need vendor MAC address prefixes (OUI
 data) and some MIBs if you want to run the daemon. The following script will
 take care of all this for you:
 
- DANCER_ENVDIR=~/environments ~/bin/localenv netdisco-deploy
-
-If you don't want that level of automation, check out the database schema diff
-from the current release of Netdisco, and apply it yourself:
-
- ~/perl5/lib/perl5/App/Netdisco/DB/schema_versions/App-Netdisco-DB-2-3-PostgreSQL.sql
+ ~/bin/netdisco-deploy
 
 =head1 Startup
 
-Run the following command to start the web-app server as a daemon (port 5000):
+Run the following command to start the web-app server as a backgrounded daemon
+(listening on port 5000):
 
- DANCER_ENVDIR=~/environments ~/bin/netdisco-web start
+ ~/bin/netdisco-web start
 
 Run the following command to start the job control daemon (port control, etc):
 
- DANCER_ENVDIR=~/environments ~/bin/netdisco-daemon start
+ ~/bin/netdisco-daemon start
 
-You should (of course) avoid running this Netdisco daemon and the legacy
-daemon at the same time.
+You should take care not to run this Netdisco daemon and the legacy daemon at
+the same time.
+
+=head1 Upgrading
+
+Before upgrading please review the latest L<Release
+Notes|App::Netdisco::Manual::ReleaseNotes>. Then, the process is as follows:
+
+ # upgrade Netdisco
+ ~/bin/localenv cpanm --notest App::Netdisco
+ 
+ # apply database schema updates (optionally, get latest OIDs/MIBs)
+ ~/bin/netdisco-deploy
+ 
+ # restart web service
+ ~/bin/netdisco-web restart
+ 
+ # optionally, restart job daemon if you use it
+ ~/bin/netdisco-daemon restart
 
 =head1 Tips and Tricks
 
+=head2 Searching
+
 The main black navigation bar has a search box which is smart enough to work
 out what you're looking for in most cases. For example device names, node IP
 or MAC addreses, VLAN numbers, and so on.
 
-For SQL debugging try the following commands:
+=head2 User Rights
 
- DBIC_TRACE_PROFILE=console DBIC_TRACE=1 \
-   DANCER_ENVDIR=~/environments ~/bin/localenv plackup ~/bin/netdisco-web-fg
-  
- DBIC_TRACE_PROFILE=console DBIC_TRACE=1 \
-   DANCER_ENVDIR=~/environments ~/bin/localenv netdisco-daemon-fg
-
-Other ways to run and host the web application can be found in the
-L<Dancer::Deployment> page. See also the L<plackup> documentation.
-
-With the default configuration user authentication is disabled and the default
-"guest" user has no special privilege. To grant port and device control rights
-to this user, create a row in the C<users> table of the Netdisco database with
-a username of C<guest> and the C<port_control> flag set to true:
+When user authentication is disabled (C<no_auth>) the default username is
+"guest", which has no special privilege. To grant port and device control
+rights to this user, create a row in the C<users> table of the Netdisco
+database with a username of C<guest> and the C<port_control> flag set to true:
 
  netdisco=> insert into users (username, port_control) values ('guest', true);
 
-=head1 Upgrading
+=head2 Deployment Scenarios
 
-Simply install this module again, then upgrade the database schema:
+More documentation on how to deploy the application in other scenarios, for
+example behind a web proxy, is in the
+L<Deployment|App::Netdisco::Manual::Deployment> documentation.
 
- ~/bin/localenv cpanm --quiet --notest App::Netdisco
- DANCER_ENVDIR=~/environments ~/bin/localenv netdisco-deploy
+=head2 Database API
 
-=head1 Future Work
+Bundled with this distribution is a L<DBIx::Class> layer for the Netdisco
+database. This abstracts away all the SQL into an elegant, re-usable OO
+interface. See the L<App::Netdisco::Developing> documentation for further
+information.
 
-Bundled with this app is a L<DBIx::Class> layer for the Netdisco database.
-This could be a starting point for an "official" DBIC layer. Helper functions
-and canned searches have been added to support the web interface.
+=head2 Plugins
 
-The intention is to support "plugins" for additonal features, most notably
-columns in the Device Port listing, but also new menu items and tabs. The
-design of this is sketched out but not implemented. The goal is to avoid
-patching core code to add localizations or less widely used features.
+App::Netdisco includes a Plugin subsystem for building the web user interface.
+Items in the navigation bar and the tabs on pages are loaded as Plugins, and
+you have control over their appearance and ordering. See
+L<App::Netdisco::Web::Plugin> for further information.
+
+=head2 Developing
+
+Lots of information about the architecture of this application is contained
+within the L<App::Netdisco::Developing> documentation.
 
 =head1 Caveats
 
 Some sections are not yet implemented, e.g. the I<Device Module> tab.
 
-Menu items on the main black navigation bar go nowhere, except Home.
+Some menu items on the main black navigation bar go nowhere.
 
 None of the Reports yet exist (e.g. searching for wireless devices, or duplex
-mismatches). These might be implemented as a plugin bundle.
+mismatches). These will be implemented as a plugin bundle.
 
 The Wireless, IP Phone and NetBIOS Node properies are not yet shown.
 
