@@ -2,17 +2,16 @@ package App::Netdisco::Web::Plugin::Inventory;
 
 use Dancer ':syntax';
 use Dancer::Plugin::DBIC;
-use Dancer::Plugin::Auth::Extensible;
 
 use App::Netdisco::Web::Plugin;
 
 register_navbar_item({
-  tag   => 'inventory',
+  id    => 'inventory',
   path  => '/inventory',
   label => 'Inventory',
 });
 
-get '/inventory' => require_login sub {
+get '/inventory' => sub {
     my $models = schema('netdisco')->resultset('Device')->get_models();
     my $releases = schema('netdisco')->resultset('Device')->get_releases();
 
