@@ -6,12 +6,12 @@ use Dancer::Plugin::DBIC;
 
 use App::Netdisco::Web::Plugin;
 
-register_search_tab({ tag => 'vlan', label => 'VLAN' });
+register_search_tab({ id => 'vlan', label => 'VLAN' });
 
 # devices carrying vlan xxx
 ajax '/ajax/content/search/vlan' => sub {
     my $q = param('q');
-    send_error('Missing query', 400) unless $q;
+    return unless $q;
     my $set;
 
     if ($q =~ m/^\d+$/) {
